@@ -49,29 +49,37 @@ RunOptionsWidget::RunOptionsWidget(QDomDocument &dom, const QString &configGroup
 
     mainprogram_edit->completionObject()->setMode(KURLCompletion::FileCompletion);
     mainprogram_edit->setMode( KFile::File | KFile::ExistingOnly | KFile::LocalOnly );
-    if( DomUtil::readEntry(dom, configGroup + "/run/mainprogram").isEmpty())
+    if( DomUtil::readEntry(dom, configGroup + "/run/mainprogram").isEmpty() && QFileInfo( buildDirectory ).exists() )
     {
         mainprogram_edit->setURL( buildDirectory );
         mainprogram_edit->fileDialog()->setURL( KURL::fromPathOrURL(buildDirectory) );
-    }else
+    }else if ( QFileInfo( DomUtil::readEntry(dom, configGroup + "/run/mainprogram") ).exists() )
     {
         QString program = DomUtil::readEntry(dom, configGroup + "/run/mainprogram");
         if( QDir::isRelativePath(program) )
             program = buildDirectory + "/" + program;
         mainprogram_edit->setURL(program);
         mainprogram_edit->fileDialog()->setURL( program );
+    }else
+    {
+        mainprogram_edit->setURL(QString());
+        mainprogram_edit->fileDialog()->setURL(QString());
     }
 
     cwd_edit->completionObject()->setMode(KURLCompletion::DirCompletion);
     cwd_edit->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
-    if( DomUtil::readEntry(dom, configGroup + "/run/globalcwd").isEmpty())
+    if( DomUtil::readEntry(dom, configGroup + "/run/globalcwd").isEmpty() && QFileInfo( buildDirectory ).exists() )
     {
         cwd_edit->setURL( buildDirectory );
         cwd_edit->fileDialog()->setURL( KURL::fromPathOrURL(buildDirectory) );
-    }else
+    }else if( QFileInfo( DomUtil::readEntry(dom, configGroup + "/run/globalcwd") ).exists() )
     {
         cwd_edit->setURL(DomUtil::readEntry(dom, configGroup + "/run/globalcwd"));
         cwd_edit->fileDialog()->setURL( KURL::fromPathOrURL( DomUtil::readEntry(dom, configGroup + "/run/globalcwd") ) );
+    }else
+    {
+        cwd_edit->setURL(QString());
+        cwd_edit->fileDialog()->setURL(QString());
     }
 
     if( configGroup == "/kdevautoproject" || configGroup == "/kdevtrollproject" )
@@ -85,8 +93,8 @@ RunOptionsWidget::RunOptionsWidget(QDomDocument &dom, const QString &configGroup
 
     // Read the main program command line arguments and store them in the edit box
 
-    runargs_edit->setURL(DomUtil::readEntry(dom, configGroup + "/run/programargs"));
-    debugargs_edit->setURL(DomUtil::readEntry(dom, configGroup + "/run/globaldebugarguments"));
+    runargs_edit->setText(DomUtil::readEntry(dom, configGroup + "/run/programargs"));
+    debugargs_edit->setText(DomUtil::readEntry(dom, configGroup + "/run/globaldebugarguments"));
 
     startinterminal_box->setChecked(DomUtil::readBoolEntry(dom, configGroup + "/run/terminal"));
     autocompile_box->setChecked(DomUtil::readBoolEntry(dom, configGroup + "/run/autocompile", false));
