@@ -52,7 +52,7 @@ GroupItem::GroupItem( QListView *lv, GroupType type, const QString &text, QMakeS
     setPixmap( 0, SmallIcon( "tar" ) );
 }
 
-GroupItem::GroupType GroupItem::groupTypeForExtension( const QString &ext, bool qt4project )
+GroupItem::GroupType GroupItem::groupTypeForExtension( const QString &ext )
 {
     if ( ext == "cpp" || ext == "cc" || ext == "c" || ext == "C" || ext == "c++" || ext == "cxx" || ext == "ocl" )
         return Sources;
@@ -60,7 +60,7 @@ GroupItem::GroupType GroupItem::groupTypeForExtension( const QString &ext, bool
         return Headers;
     else if ( ext == "ui" )
         return Forms;
-    else if ( qt4project && ( ext == "jpg" || ext == "jpeg" || ext == "png" || ext == "xpm" || ext == "gif" || ext == "bmp" ) )
+    else if ( ext == "jpg" || ext == "jpeg" || ext == "png" || ext == "xpm" || ext == "gif" || ext == "bmp" )
         return Images;
     else if ( ext == "idl" )
         return IDLs;
@@ -149,8 +149,6 @@ void GroupItem::paintCell( QPainter* p, const QColorGroup& c, int column, int wi
 void GroupItem::addFileToScope( const QString& filename )
 {
     QString file = filename;
-    if( filename.find(QRegExp("[ \t]") ) != -1 )
-        file = "\""+file+"\"";
 
     QPtrListIterator<FileItem> it( files );
     while ( it.current() != 0 )
@@ -210,12 +208,15 @@ void GroupItem::addFileToScope( const QString& filename )
 
 void GroupItem::removeFileFromScope( const QString& filename )
 {
+    QString filePath;
+
     QPtrListIterator<FileItem> it( files );
     while ( it.current() != 0 )
     {
         if ( it.current() ->text( 0 ) == filename )      //File already exists in this subproject
         {
             FileItem * fitem = it.current();
+            filePath = fitem->localFilePath;
             files.remove( it );
             delete fitem;
             break;
@@ -225,47 +226,47 @@ void GroupItem::removeFileFromScope( const QString& filename )
 
     if ( groupType == GroupItem::Sources )
     {
-        owner->removeValue( "SOURCES", filename );
+        owner->removeValue( "SOURCES", filePath );
     }
     else if ( groupType == GroupItem::Headers )
     {
-        owner->removeValue( "HEADERS", filename );
+        owner->removeValue( "HEADERS", filePath );
     }
     else if ( groupType == GroupItem::Forms )
     {
-        owner->removeValue( "FORMS", filename );
-    }
-    else if ( groupType == GroupItem::Distfiles )
-    {
-        owner->removeValue( "DISTFILES", filename );
+        owner->removeValue( "FORMS", filePath );
     }
     else if ( groupType == GroupItem::Images )
     {
-        owner->removeValue( "IMAGES", filename );
+        owner->removeValue( "IMAGES", filePath );
     }
     else if ( groupType == GroupItem::Resources )
     {
-        owner->removeValue( "RESOURCES", filename );
+        owner->removeValue( "RESOURCES", filePath );
     }
     else if ( groupType == GroupItem::Lexsources )
     {
-        owner->removeValue( "LEXSOURCES", filename );
+        owner->removeValue( "LEXSOURCES", filePath );
     }
     else if ( groupType == GroupItem::Yaccsources )
     {
-        owner->removeValue( "YACCSOURCES", filename );
+        owner->removeValue( "YACCSOURCES", filePath );
     }
     else if ( groupType == GroupItem::Translations )
     {
-        owner->removeValue( "TRANSLATIONS", filename );
+        owner->removeValue( "TRANSLATIONS", filePath );
     }
     else if ( groupType == GroupItem::IDLs )
     {
-        owner->removeValue( "IDL", filename );
+        owner->removeValue( "IDL", filePath );
+    }
+    else if ( groupType == GroupItem::Distfiles )
+    {
+        owner->removeValue( "DISTFILES", filePath );
     }
     else if ( groupType == GroupItem::InstallObject )
     {
-        owner->removeValue( text( 0 ) + ".files", filename );
+        owner->removeValue( text( 0 ) + ".files", filePath );
     }
     owner->scope->saveToFile();
 }
@@ -491,6 +492,8 @@ void QMakeScopeItem::buildSubTree()
 {
     QValueList<Scope*>::const_iterator it;
 
+    sortChildItems( 0, false );
+
     QValueList<Scope*> scopes = scope->scopesInOrder();
 
     for ( it = scopes.begin(); it != scopes.end(); ++it )
@@ -500,7 +503,6 @@ void QMakeScopeItem::buildSubTree()
         else
             kdDebug( 9024 ) << "No QMakeScopeItem created" << endl;
     }
-    sortChildItems( 0, true );
 }
 
 
@@ -524,7 +526,7 @@ void QMakeScopeItem::init()
         if( scope->isEnabled() )
         {
             if ( tmp.findIndex( "subdirs" ) != -1 )
-                setPixmap( 0, SmallIcon( "qmake_sub" ) );
+                setPixmap( 0, SmallIcon( "folder" ) );
             else if ( tmp.findIndex( "lib" ) != -1 )
                 setPixmap( 0, SmallIcon( "qmake_lib" ) );
             else
@@ -532,7 +534,7 @@ void QMakeScopeItem::init()
         }else
         {
             if ( tmp.findIndex( "subdirs" ) != -1 )
-                setPixmap( 0, SmallIcon( "qmake_sub_disabled" ) );
+                setPixmap( 0, SmallIcon( "folder_grey" ) );
             else if ( tmp.findIndex( "lib" ) != -1 )
                 setPixmap( 0, SmallIcon( "qmake_lib_disabled" ) );
             else
@@ -557,8 +559,18 @@ GroupItem* QMakeScopeItem::createGroupItem( GroupItem::GroupType type, const QSt
 
 FileItem* QMakeScopeItem::createFileItem( const QString& name )
 {
-    FileItem * fitem = new FileItem( listView(), name );
+    QString display = name;
+    if( m_widget->showFilenamesOnly() )
+    {
+        int dirSepPos = name.findRev( QChar( QDir::separator() ) );
+        if  ( dirSepPos != - 1 )
+            display = name.mid( dirSepPos + 1 );
+    }
+    FileItem * fitem = new FileItem( listView(), display );
     listView() ->takeItem( fitem );
+
+    fitem->localFilePath = name;
+
     return fitem;
 }
 
@@ -627,15 +639,12 @@ void QMakeScopeItem::buildGroups()
             item->files.append( createFileItem( *it ) );
         }
     }
-    else
+    values = scope->variableValues( "IMAGES" );
+    item = createGroupItem( GroupItem::Images, "IMAGES", this );
+    groups.insert( item->groupType, item );
+    for ( it = values.begin(); it != values.end(); ++it )
     {
-        values = scope->variableValues( "IMAGES" );
-        item = createGroupItem( GroupItem::Images, "IMAGES", this );
-        groups.insert( item->groupType, item );
-        for ( it = values.begin(); it != values.end(); ++it )
-        {
-            item->files.append( createFileItem( *it ) );
-        }
+        item->files.append( createFileItem( *it ) );
     }
 
     values = scope->variableValues( "TRANSLATIONS" );
