@@ -12,6 +12,7 @@ email                : david.nolden.kdevelop@art-master.de
  *                                                                         *
  ***************************************************************************/
 #include <qtl.h>
+#include <typeinfo>
 #include "simpletypenamespace.h"
 #include "simpletypecachebinder.h"
 
@@ -31,14 +32,14 @@ TypePointer SimpleTypeNamespace::clone() {
 
 SimpleTypeNamespace::SimpleTypeNamespace( const QStringList& fakeScope, const QStringList& realScope ) : SimpleTypeImpl( fakeScope ), m_currentSlaveId(0) {
   ifVerbose( dbg() << "\"" << str() << "\": created namespace-proxy with real scope \"" << realScope.join( "::" ) << "\"" << endl );
-  SimpleType cm = SimpleType( realScope, HashedStringSet(), CodeModel );
-  SimpleType ct = SimpleType( realScope, HashedStringSet(), Catalog );
+  SimpleType cm = SimpleType( realScope, HashedStringSet(), RepoCodeModel );
+  SimpleType ct = SimpleType( realScope, HashedStringSet(), RepoCatalog );
   cm = SimpleType( cm->clone() );
   ct = SimpleType( ct->clone() );
   cm->setMasterProxy( this );
   ct->setMasterProxy( this );
-  addImport( ct->desc() );
   addImport( cm->desc() );
+  addImport( ct->desc() );
 }
 
 SimpleTypeNamespace::SimpleTypeNamespace( const QStringList& fakeScope ) : SimpleTypeImpl( fakeScope ), m_currentSlaveId(0) {
