@@ -13,7 +13,9 @@
 #include "kdevappfrontend.h"
 #include "kdevplugininfo.h"
 #include "kdevshellwidget.h"
+#include "kdevquickopen.h"
 
+#include <qdir.h>
 #include <qwhatsthis.h>
 #include <qtimer.h>
 #include <qfileinfo.h>
@@ -53,6 +55,11 @@ RubySupportPart::RubySupportPart(QObject *parent, const char *name, const QStrin
   action->setToolTip(i18n("Launch Browser"));
   action->setWhatsThis(i18n("<b>Launch Browser</b><p>Opens a web browser pointing to the Ruby Rails server") );
 
+  action = new KAction( i18n("Switch To Controller"), 0, CTRL+ALT+Key_1, this, SLOT(slotSwitchToController()), actionCollection(), "switch_to_controller" );
+  action = new KAction( i18n("Switch To Model"), 0, CTRL+ALT+Key_2, this, SLOT(slotSwitchToModel()), actionCollection(), "switch_to_model" );
+  action = new KAction( i18n("Switch To View"), 0, CTRL+ALT+Key_3, this, SLOT(slotSwitchToView()), actionCollection(), "switch_to_view" );
+  action = new KAction( i18n("Switch To Test"), 0, CTRL+ALT+Key_4, this, SLOT(slotSwitchToTest()), actionCollection(), "switch_to_test" );
+
   kdDebug() << "Creating RubySupportPart" << endl;
 
   m_shellWidget = new KDevShellWidget( 0, "irb console");
@@ -657,4 +664,187 @@ void RubySupportPart::slotBrowse()
     kapp->invokeBrowser("http://localhost:3000/");
 }
 
+void RubySupportPart::slotSwitchToController()
+{
+    KParts::Part *activePart = partController()->activePart();
+    if (!activePart)
+        return;
+    KParts::ReadOnlyPart *ropart = dynamic_cast<KParts::ReadOnlyPart*>(activePart);
+    if (!ropart)
+        return;
+    QFileInfo file(ropart->url().path());
+    if (!file.exists())
+        return;
+    QString ext = file.extension();
+    QString name = file.baseName();
+    QString switchTo = "";
+    if ((ext == "rb") && !name.endsWith("_controller"))
+    {
+        if (name.endsWith("_test"))
+        {
+            switchTo = name.remove(QRegExp("_test$"));  //the file is the test
+            switchTo = name.remove(QRegExp("_controller$"));  //remove functional test name parts
+        }
+        else
+            switchTo = name;
+    }
+    else if (ext == "rjs" || ext == "rxml" || ext == "rhtml")
+    {
+        //this is a view, we need to find the directory of this view and try to find
+        //the controller basing on the directory information
+        switchTo = file.dir().dirName();
+    }
+    QString controllersDir = project()->projectDirectory() + "/app/controllers/";
+    if (!switchTo.isEmpty())
+    {
+        if (switchTo.endsWith("s"))
+            switchTo = switchTo.mid(0, switchTo.length()-1);
+        QString singular = controllersDir + switchTo + "_controller.rb";
+        QString plural = controllersDir + switchTo + "s_controller.rb";
+        KURL url = KURL::fromPathOrURL(QFile::exists(singular) ? singular : plural);
+        partController()->editDocument(url);
+    }
+}
+
+void RubySupportPart::slotSwitchToTest()
+{
+    KParts::Part *activePart = partController()->activePart();
+    if (!activePart)
+        return;
+    KParts::ReadOnlyPart *ropart = dynamic_cast<KParts::ReadOnlyPart*>(activePart);
+    if (!ropart)
+        return;
+    QFileInfo file(ropart->url().path());
+    if (!file.exists())
+        return;
+    QString ext = file.extension();
+    QString name = file.baseName();
+    QString switchTo = "";
+
+    if (ext == "rjs" || ext == "rxml" || ext == "rhtml")
+    {
+        //this is a view already, let's show the list of all views for this model
+        switchTo = file.dir().dirName();
+    }
+    else if (ext == "rb")
+        switchTo = name.remove(QRegExp("_controller$")).remove(QRegExp("_controller_test$")).remove(QRegExp("_test$"));
+
+    if (switchTo.isEmpty())
+        return;
+
+    if (switchTo.endsWith("s"))
+        switchTo = switchTo.mid(0, switchTo.length() - 1);
+
+    KURL::List urls;
+    QString testDir = project()->projectDirectory() + "/test/";
+    QString functionalTestS = testDir + "functional/" + switchTo + "_controller_test.rb";
+    QString functionalTestP = testDir + "functional/" + switchTo + "s_controller_test.rb";
+    QString integrationTestS = testDir + "integration/" + switchTo + "_test.rb";
+    QString integrationTestP = testDir + "integration/" + switchTo + "s_test.rb";
+    QString unitTestS = testDir + "unit/" + switchTo + "_test.rb";
+    QString unitTestP = testDir + "unit/" + switchTo + "s_test.rb";
+    if (QFile::exists(functionalTestP)) urls << KURL::fromPathOrURL(functionalTestP);
+    if (QFile::exists(integrationTestP)) urls << KURL::fromPathOrURL(integrationTestP);
+    if (QFile::exists(unitTestP)) urls << KURL::fromPathOrURL(unitTestP);
+    if (QFile::exists(functionalTestS)) urls << KURL::fromPathOrURL(functionalTestS);
+    if (QFile::exists(integrationTestS)) urls << KURL::fromPathOrURL(integrationTestS);
+    if (QFile::exists(unitTestS)) urls << KURL::fromPathOrURL(unitTestS);
+
+    KDevQuickOpen *qo = extension<KDevQuickOpen>("KDevelop/QuickOpen");
+    if (qo && !urls.isEmpty())
+        qo->quickOpenFile(urls);
+}
+
+void RubySupportPart::slotSwitchToModel()
+{
+    KParts::Part *activePart = partController()->activePart();
+    if (!activePart)
+        return;
+    KParts::ReadOnlyPart *ropart = dynamic_cast<KParts::ReadOnlyPart*>(activePart);
+    if (!ropart)
+        return;
+    QFileInfo file(ropart->url().path());
+    if (!file.exists())
+        return;
+    QString ext = file.extension();
+    QString name = file.baseName();
+    QString switchTo = "";
+
+    if (ext == "rjs" || ext == "rxml" || ext == "rhtml")
+    {
+        //this is a view already, let's show the list of all views for this model
+        switchTo = file.dir().dirName();
+    }
+    else if (ext == "rb" && (name.endsWith("_controller") || name.endsWith("_test")))
+    {
+        switchTo = name.remove(QRegExp("_controller$")).remove(QRegExp("_controller_test$")).remove(QRegExp("_test$"));
+    }
+
+    if (switchTo.isEmpty())
+        return;
+
+    if (switchTo.endsWith("s"))
+        switchTo = switchTo.mid(0, switchTo.length() - 1);
+
+    QString modelsDir = project()->projectDirectory() + "/app/models/";
+    QString singular = modelsDir + switchTo + "_controller.rb";
+    QString plural = modelsDir + switchTo + "s_controller.rb";
+    KURL url = KURL::fromPathOrURL(QFile::exists(singular) ? singular : plural);
+
+    partController()->editDocument(KURL::fromPathOrURL(modelsDir + switchTo + ".rb"));
+}
+
+void RubySupportPart::slotSwitchToView()
+{
+    KParts::Part *activePart = partController()->activePart();
+    if (!activePart)
+        return;
+    KParts::ReadOnlyPart *ropart = dynamic_cast<KParts::ReadOnlyPart*>(activePart);
+    if (!ropart)
+        return;
+    QFileInfo file(ropart->url().path());
+    if (!file.exists())
+        return;
+    QString ext = file.extension();
+    QString name = file.baseName();
+    QString switchTo = "";
+
+    if (ext == "rjs" || ext == "rxml" || ext == "rhtml")
+    {
+        //this is a view already, let's show the list of all views for this model
+        switchTo = file.dir().dirName();
+    }
+    else if (ext == "rb")
+        switchTo = name.remove(QRegExp("_controller$")).remove(QRegExp("_controller_test$")).remove(QRegExp("_test$"));
+
+    if (switchTo.isEmpty())
+        return;
+
+    if (switchTo.endsWith("s"))
+        switchTo = switchTo.mid(0, switchTo.length() - 1);
+
+    KURL::List urls;
+    QDir viewsDir;
+    QDir viewsDirS = QDir(project()->projectDirectory() + "/app/views/" + switchTo);
+    QDir viewsDirP = QDir(project()->projectDirectory() + "/app/views/" + switchTo + "s");
+    if (viewsDirS.exists())
+        viewsDir = viewsDirS;
+    else if (viewsDirP.exists())
+        viewsDir = viewsDirP;
+    else
+        return;
+
+    QStringList views = viewsDir.entryList();
+
+    for (QStringList::const_iterator it = views.begin(); it != views.end(); ++it)
+    {
+        QString viewName = *it;
+        if ( !(viewName.endsWith("~") || viewName == "." || viewName == "..") )
+            urls << KURL::fromPathOrURL(viewsDir.absPath() + "/" + viewName);
+    }
+    KDevQuickOpen *qo = extension<KDevQuickOpen>("KDevelop/QuickOpen");
+    if (qo)
+        qo->quickOpenFile(urls);
+}
+
 #include "rubysupport_part.moc"
