@@ -1,7 +1,8 @@
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
+ * $Id: String.cpp 626096 2007-01-22 06:35:06Z okellogg $
  */
 
 #include "antlr/String.hpp"
@@ -17,6 +18,14 @@
 #ifdef ANTLR_CXX_SUPPORTS_NAMESPACE
 namespace antlr {
 #endif
+
+// wh: hack for Borland C++ 5.6
+#if __BORLANDC__
+  using std::sprintf;
+#endif
+
+
+// RK: should be using snprintf actually... (or stringstream)
 ANTLR_C_USING(sprintf)
 
 ANTLR_USE_NAMESPACE(std)string operator+( const ANTLR_USE_NAMESPACE(std)string& lhs, const int rhs )
@@ -26,6 +35,13 @@ ANTLR_USE_NAMESPACE(std)string operator+( const ANTLR_USE_NAMESPACE(std)string&
 	return lhs+tmp;
 }
 
+ANTLR_USE_NAMESPACE(std)string operator+( const ANTLR_USE_NAMESPACE(std)string& lhs, size_t rhs )
+{
+	char tmp[100];
+	sprintf(tmp,"%u",rhs);
+	return lhs+tmp;
+}
+
 /** Convert character to readable string
  */
 ANTLR_USE_NAMESPACE(std)string charName(int ch)
@@ -36,6 +52,8 @@ ANTLR_USE_NAMESPACE(std)string charName(int ch)
 	{
 		ANTLR_USE_NAMESPACE(std)string s;
 
+		// when you think you've seen it all.. an isprint that crashes...
+		ch = ch & 0xFF;
 #ifdef ANTLR_CCTYPE_NEEDS_STD
 		if( ANTLR_USE_NAMESPACE(std)isprint( ch ) )
 #else
