@@ -28,6 +28,7 @@
 #include <kapplication.h>
 #include <kactionclasses.h>
 #include <kpopupmenu.h>
+#include <kmessagebox.h>
 
 #include "kdevcore.h"
 #include "kdevmainwindow.h"
@@ -51,6 +52,8 @@
 
 #include "kdevplugininfo.h"
 
+#include "config.h"
+
 static const KDevPluginInfo data("kdevfilecreate");
 
 typedef KDevGenericFactory<FileCreatePart> FileCreateFactory;
@@ -177,7 +180,10 @@ void FileCreatePart::slotNewFilePopup( int pFileType )
 
 void FileCreatePart::slotNewFile() {
   KDevCreateFile::CreatedFile createdFile = createNewFile();
-  openCreatedFile(createdFile);
+  if (createdFile.status == KDevCreateFile::CreatedFile::STATUS_NOTCREATED)
+    KMessageBox::error(0, i18n("Cannot create file. Check whether the directory and filename are valid."));
+  else if (createdFile.status != KDevCreateFile::CreatedFile::STATUS_CANCELED)
+    openCreatedFile(createdFile);
 }
 
 void FileCreatePart::slotProjectOpened() {
@@ -367,7 +373,7 @@ KDevCreateFile::CreatedFile FileCreatePart::createNewFile(QString ext, QString d
   int dialogResult = dialog.exec();
 
   if (dialogResult == KDialogBase::Rejected) {
-    result.status = KDevCreateFile::CreatedFile::STATUS_NOTCREATED;
+    result.status = KDevCreateFile::CreatedFile::STATUS_CANCELED;
     return result;
   }
 
@@ -399,13 +405,21 @@ KDevCreateFile::CreatedFile FileCreatePart::createNewFile(QString ext, QString d
       ext += "-" + subtype;
 
   // create file from template
-  if (!FileTemplate::exists(this, ext) ||
-      !FileTemplate::copy(this, ext, fullPath) ) {
+  bool created = false;
+  if (FileTemplate::exists(this, ext))
+      created = FileTemplate::copy(this, ext, fullPath);
+  else {
       // no template, create a blank file instead
       QFile f(fullPath);
-      f.open( IO_WriteOnly );
+      created = f.open( IO_WriteOnly );
       f.close();
   }
+  if (!created)
+  {
+      result.status = KDevCreateFile::CreatedFile::STATUS_NOTCREATED;
+      return result;
+  }
+
   if (dialog.addToProject())
   {
     // work out the path relative to the project directory
@@ -421,12 +435,10 @@ KDevCreateFile::CreatedFile FileCreatePart::createNewFile(QString ext, QString d
         project()->addFile(relToProj.mid(1));
 	  }
   }
-  else
-  {
-    KURL url;
-    url.setPath(fullPath);
-    partController()->editDocument(url);
-  }
+
+  KURL url;
+  url.setPath(fullPath);
+  partController()->editDocument(url);
 
   QString fileName = URLUtil::filename(fullPath);
   kdDebug(9034) << "file name = " << filename << endl;
@@ -508,15 +520,38 @@ void FileCreatePart::slotInitialize( )
   }
 }
 
+QString FileCreatePart::findGlobalXMLFile() const
+{
+  int version = 0;
+  QString filename;
+  QStringList filenames = KGlobal::instance()->dirs()->findAllResources("data", "kdevfilecreate/template-info.xml");
+  for( QStringList::const_iterator it = filenames.begin(); it != filenames.end(); ++it )
+  {
+    QDomDocument globalDom;
+    DomUtil::openDOMFile(globalDom,*it);
+    QDomElement e = globalDom.documentElement();
+    if( !e.hasAttribute( "version" ) && e.attribute( "version" ).toInt() < version )
+    {
+      continue;
+    }else
+    {
+      version = e.attribute( "version" ).toInt();
+      filename = *it;
+    }
+  }
+  return filename;
+}
+
 void FileCreatePart::slotGlobalInitialize( )
 {
   // read in global template information
-  QString globalXMLFile = ::locate("data", "kdevfilecreate/template-info.xml");
+  QString globalXMLFile = findGlobalXMLFile();
   kdDebug(9034) << "Found global template info info " << globalXMLFile << endl;
   QDomDocument globalDom;
-  if (!globalXMLFile.isNull() &&
-      DomUtil::openDOMFile(globalDom,globalXMLFile)) {
+  if (!globalXMLFile.isNull() && DomUtil::openDOMFile(globalDom,globalXMLFile))
+  {
     kdDebug(9034) << "Reading global template info..." << endl;
+
     readTypes(globalDom, m_filetypes, false);
 
   }
@@ -524,4 +559,4 @@ void FileCreatePart::slotGlobalInitialize( )
 
 #include "filecreate_part.moc"
 
-	// kate: indent-width 4; replace-tabs off; tab-width 4; space-indent off;
+// kate: indent-width 2; replace-tabs on; tab-width 4; space-indent on;
