@@ -65,14 +65,6 @@
 
 #include "shellextension.h"
 
-#ifdef KDE_MAKE_VERSION
-# if KDE_VERSION < KDE_MAKE_VERSION(3,1,90)
-#  define NEED_CONFIGHACK
-# endif
-#else
-# define NEED_CONFIGHACK
-#endif
-
 using namespace MainWindowUtils;
 
 MainWindowShare::MainWindowShare(QObject* pParent, const char* name)
@@ -347,21 +339,6 @@ void MainWindowShare::slotConfigureEditors()
     conf->configDialog();
     conf->writeConfig();
 
-#ifdef NEED_CONFIGHACK
-    // iterate over other instances of this part type and apply configuration
-    if( const QPtrList<KParts::Part> * partlist = partController->parts() )
-    {
-        QPtrListIterator<KParts::Part> it( *partlist );
-        while ( KParts::Part* p = it.current() )
-        {
-            if ( KTextEditor::ConfigInterface * ci = dynamic_cast<KTextEditor::ConfigInterface *>( p ) )
-            {
-                ci->readConfig();
-            }
-            ++it;
-        }
-    }
-#endif
 }
 
 void MainWindowShare::slotGUICreated( KParts::Part * part )
