@@ -468,9 +468,8 @@ void subversionPart::slotLog()
 		QString revkindstart = dlg.revKindStart();
 		int revend = dlg.revend();
 		QString revkindend = dlg.revKindEnd();
-		bool reposit = dlg.repositLog();
 		bool strictNode = dlg.strictNode();
-		m_impl->svnLog (m_urls, revstart, revkindstart, revend, revkindend, reposit, true/*changedPath*/, strictNode);	
+		m_impl->svnLog (m_urls, revstart, revkindstart, revend, revkindend, true/*changedPath*/, strictNode);
 	} else{
 		return;
 	}
@@ -488,8 +487,7 @@ void subversionPart::slotBlame()
 		return;
 	}
 	KURL url = m_urls.first();
-// 	m_impl->blame(url, repositBlame, int revstart, QString revKindStart, int revend, QString revKindEnd);
-	m_impl->blame(url, SvnGlobal::path_to_reposit, 0, "", -1, "HEAD");
+	m_impl->blame(url, SvnGlobal::path_to_reposit, 0, "", -1, "BASE");
 }
 
 void subversionPart::slotDel() {
