@@ -766,14 +766,13 @@ void kio_svnProtocol::special( const QByteArray& data ) {
 				kdDebug(9036) << "kio_svnProtocol LOG" << endl;
 				int revstart, revend;
 				QString revkindstart, revkindend;
-                bool repositLog, discorverChangedPath, strictNodeHistory;
+                bool discorverChangedPath, strictNodeHistory;
 				KURL::List targets;
 
 				stream >> revstart;
 				stream >> revkindstart;
 				stream >> revend;
 				stream >> revkindend;
-				stream >> repositLog;
                 stream >> discorverChangedPath;
                 stream >> strictNodeHistory;
 				while ( !stream.atEnd() ) {
@@ -782,7 +781,7 @@ void kio_svnProtocol::special( const QByteArray& data ) {
 					targets << tmp;
 				}
 				svn_log( revstart, revkindstart, revend, revkindend,
-                         repositLog, discorverChangedPath, strictNodeHistory, targets );
+                         discorverChangedPath, strictNodeHistory, targets );
 				break;
 			}
 		case SVN_IMPORT:
@@ -893,7 +892,7 @@ void kio_svnProtocol::special( const QByteArray& data ) {
 			{
 				KURL url1,url2;
 				int rev1, rev2;
-				bool recurse;
+				bool recurse, pegdiff;
 				QString revkind1, revkind2;
 				stream >> url1;
 				stream >> url2;
@@ -901,9 +900,9 @@ void kio_svnProtocol::special( const QByteArray& data ) {
 				stream >> revkind1;
 				stream >> rev2;
 				stream >> revkind2;
-				stream >> recurse;
+				stream >> recurse >> pegdiff;
 				kdDebug(9036) << "kio_svnProtocol DIFF" << endl;
-				svn_diff(url1,url2,rev1,rev2,revkind1,revkind2,recurse);
+				svn_diff(url1,url2,rev1,rev2,revkind1,revkind2,recurse,pegdiff);
 				break;
 			}
 		case SVN_BLAME:
@@ -984,7 +983,7 @@ void kio_svnProtocol::popupMessage( const QString& message ) {
 // 		kdWarning() << "Communication with KDED:KSvnd failed" << endl;
 }
 
-void kio_svnProtocol::blame( KURL url, UrlMode mode,/* int pegRev, QString pegRevKind,*/ int startRev, QString startRevKind, int endRev, QString endRevKind )
+void kio_svnProtocol::blame( KURL url, UrlMode /*mode*/,/* int pegRev, QString pegRevKind,*/ int startRev, QString startRevKind, int endRev, QString endRevKind )
 {
 	kdDebug(9036) << " __TIME__ " << __TIME__ << endl;
 // 	kdDebug(9036) << " PegRev " << pegRev << pegRevKind << endl;
@@ -992,43 +991,12 @@ void kio_svnProtocol::blame( KURL url, UrlMode mode,/* int pegRev, QString pegRe
 	kdDebug(9036) << " EndRev" << endRev << endRevKind << endl;
 
 	apr_pool_t *subpool = svn_pool_create (pool);
-	const char* path_or_url=0;
+	const char* path_or_url = apr_pstrdup( subpool, url.pathOrURL().utf8() );;
 
 	svn_opt_revision_t rev1 = createRevision( startRev, startRevKind, subpool );
 	svn_opt_revision_t rev2 = createRevision( endRev, endRevKind, subpool );
 // 	svn_opt_revision_t revPeg = createRevision( pegRev, pegRevKind, subpool );
 
-	// fill out "path_or_url"
-	if (mode == path_to_reposit ) {
-		svn_error_t *urlErr=0;
-		// output of svn_client_url_from_path could be the same with url.path().utf8()
-		// In that case, path_or_url just points to url.path().utf8(), which will be destroyed outside the if(){}
-		// Thus, we should allocate new memory
-		const char* orig_path = apr_pstrdup( subpool, url.path().utf8() );
-		urlErr = svn_client_url_from_path( &path_or_url, orig_path, subpool );
-		kdDebug(9036) << " __LINE__ " << __LINE__ << endl;
-		if (urlErr || !path_or_url ){
-			error( KIO::ERR_SLAVE_DEFINED,
-				   i18n("Fail to retrieve repository URL of request file. Check whether requested item is under version control"));
-		}
-		if (QString(path_or_url).isEmpty()){
-			error( KIO::ERR_SLAVE_DEFINED, i18n("Converted repository URL is empty. Check whether requested item is under version control"));
-		}
-		kdDebug(9036) << " URL from PATH: " << path_or_url << endl;
-	} else if (mode == path_to_path ){
-		url.setProtocol( "file" );
-		// svn_path_canonicalize is also the same with the above case. Needs explicit memory allocation.
-		path_or_url = apr_pstrdup( subpool, svn_path_canonicalize( url.path().utf8(), subpool ) );
-		kdDebug(9036) << " Working Copy Path: " << path_or_url << endl;
-	} else {
-        svn_string_t *string = svn_string_create( url.pathOrURL().utf8(), subpool );
-        path_or_url = string->data;
-        kdDebug(9036) << " Untouched URL or Path: " << path_or_url << endl;
-    }
-    if( !path_or_url ){
-        svn_pool_destroy (subpool);
-        error( KIO::ERR_SLAVE_DEFINED, i18n("Fail to retrieve target path or URL") );
-    }
     //initNotifier(false, false, false, subpool);
 	svn_client_blame_receiver_t receiver = kio_svnProtocol::blameReceiver;
 	svn_error_t *err = svn_client_blame( path_or_url, &rev1, &rev2, receiver, (void*)this, ctx, subpool );
@@ -1058,7 +1026,7 @@ svn_error_t* kio_svnProtocol::blameReceiver( void *baton, apr_int64_t line_no, s
 	Thus, svn_log should get another flag (bool repositHistory )specifying between file:/// or URL
 */
 void kio_svnProtocol::svn_log( int revstart, const QString& revkindstart, int revend, const QString& revkindend,
-							bool repositLog, bool discorverChangedPaths, bool strictNodeHistory,
+							bool discorverChangedPaths, bool strictNodeHistory,
 							const KURL::List& urls )
 {
 // 	kdDebug(9036) << " from revision " << revstart << " or " << revkindstart << " to " << " revision " << revend << " or " << revkindend << endl;
@@ -1072,37 +1040,18 @@ void kio_svnProtocol::svn_log( int revstart, const QString& revkindstart, int re
 
 	m_counter = 0;
 	apr_array_header_t *targets = apr_array_make(subpool, 1+urls.count(), sizeof(const char *));
-	QString convertedPathUrl;
-	
+
 	for ( QValueListConstIterator<KURL> it = urls.begin(); it != urls.end() ; ++it ) {
 		KURL nurl = *it;
+		const char *path =
+				apr_pstrdup( subpool, svn_path_canonicalize( nurl.pathOrURL().utf8(), subpool ) );
+		kdDebug(9036) << path << endl;
+		*(( const char ** )apr_array_push(( apr_array_header_t* )targets)) = path;
 
-		if ( repositLog ){ // show repository log
-			const char *urlFromPath=0;
-			svn_error_t *urlErr=0;
-			urlErr = svn_client_url_from_path( &urlFromPath, nurl.path().utf8(), subpool );
-			if (urlErr || !urlFromPath ){
-				error( KIO::ERR_SLAVE_DEFINED,
-					   i18n("Fail to retrieve repository URL of request file/dir. Check whether requested item is under version control"));
-			}
-			if (QString(urlFromPath).isEmpty()){
-				error( KIO::ERR_SLAVE_DEFINED, i18n("Converted repository URL is empty. Check whether requested item is under version control"));
-			}
-			(*(( const char ** )apr_array_push(( apr_array_header_t* )targets)) ) =
-				urlFromPath;
-			convertedPathUrl = QString::fromUtf8(urlFromPath);
-			kdDebug(9036) << " urlFromPath: " << urlFromPath << endl;
-			
-		}else{ // show working copy log
-			nurl.setProtocol( "file" );
-			convertedPathUrl = QString::fromUtf8( svn_path_canonicalize( nurl.path().utf8(), subpool ) );
-			(*(( const char ** )apr_array_push(( apr_array_header_t* )targets)) ) =
-				svn_path_canonicalize( nurl.path().utf8(), subpool );
-		}
-		setMetaData(QString::number( counter() ).rightJustify( 10,'0' )+ "requrl", convertedPathUrl );
+		setMetaData(QString::number( counter() ).rightJustify( 10,'0' )+ "requrl", nurl.pathOrURL() );
 		incCounter();
 	}
-	
+
 	svn_log_message_receiver_t receiver = kio_svnProtocol::receiveLogMessage;
 	svn_error_t *err = svn_client_log2(targets, &rev1, &rev2, 0, discorverChangedPaths, strictNodeHistory, receiver, this, ctx, subpool);
 	if ( err ){
@@ -1174,7 +1123,8 @@ svn_opt_revision_t kio_svnProtocol::createRevision( int revision, const QString&
 	return result;
 }
 
-void kio_svnProtocol::svn_diff(const KURL & url1, const KURL& url2,int rev1, int rev2,const QString& revkind1,const QString& revkind2,bool recurse) {
+void kio_svnProtocol::svn_diff(const KURL & url1, const KURL& url2,int rev1, int rev2,const QString& revkind1,const QString& revkind2,bool recurse, bool pegdiff )
+{
 	kdDebug(9036) << "kio_svn::diff : " << url1.path() << " at revision " << rev1 << " or " << revkind1 << " with "
 		<< url2.path() << " at revision " << rev2 << " or " << revkind2
 		<< endl ;
@@ -1218,7 +1168,16 @@ void kio_svnProtocol::svn_diff(const KURL & url1, const KURL& url2,int rev1, int
 	apr_file_mktemp( &outfile, templ , APR_READ|APR_WRITE|APR_CREATE|APR_TRUNCATE, subpool );
 
 	initNotifier(false, false, false, subpool);
-	svn_error_t *err = svn_client_diff (options, path1, &revision1, path2, &revision2, recurse, false, true, outfile, NULL, ctx, subpool);
+	svn_error_t *err = 0;
+	if( pegdiff ){
+		svn_opt_revision_t peg_rev = createRevision(-1, "BASE", subpool );
+		err = svn_client_diff_peg( options, path1, &peg_rev, &revision1, &revision2,
+								recurse, false, false, outfile, NULL, ctx, subpool );
+	} else{
+		err = svn_client_diff( options, path1, &revision1, path2, &revision2, recurse,
+							false, false, outfile, NULL, ctx, subpool );
+	}
+
 	if ( err ){
 		error( KIO::ERR_SLAVE_DEFINED, QString::fromLocal8Bit(err->message) );
 		svn_pool_destroy (subpool);
@@ -1765,7 +1724,7 @@ svn_error_t *kio_svnProtocol::trustSSLPrompt(svn_auth_cred_ssl_server_trust_t **
 		*cred_p = (svn_auth_cred_ssl_server_trust_t*)apr_pcalloc (pool, sizeof (svn_auth_cred_ssl_server_trust_t));
 		kdDebug(9036) << " accept permanently " << endl;
 		(*cred_p)->may_save = true;
-		(*cred_p)->accepted_failures = 0;
+		(*cred_p)->accepted_failures = failures;
 	} else{
 		kdWarning() << " SSL server trust failed for some reason" << endl;
 		*cred_p = 0L;
